@@ -18,17 +18,17 @@
 
 ****************************************/
 
-#ifndef KPAT_CARDMAPS_H
-#define KPAT_CARDMAPS_H
+#ifndef CARDMAPS_H
+#define CARDMAPS_H
 
 #include "card.h"
-//Added by qt3to4:
-#include <QPixmap>
-#include "cardcache.h"
-
 class cardMapPrivate;
+
 class KConfigGroup;
 
+#include <QtGui/QPixmap>
+
+
 class cardMap : public QObject
 {
     Q_OBJECT
@@ -38,9 +38,10 @@ public:
     cardMap();
     ~cardMap();
 
-    double wantedCardWidth() const;
-    double wantedCardHeight() const;
-    void setWantedCardWidth( double w );
+    QSize cardSize() const;
+    int cardWidth() const;
+    int cardHeight() const;
+    void setCardWidth( int width );
 
     QPixmap renderBackside( int variant = -1 );
     QPixmap renderFrontside( Card::Rank, Card::Suit );
@@ -50,6 +51,7 @@ public:
 
 public slots:
     void triggerRescale();
+    void loadInBackground();
 
 private:
     cardMapPrivate *d;
