@@ -1,11 +1,10 @@
 #ifndef DEMO_H
 #define DEMO_H
 
-#include <QWidget>
-#include <QPixmap>
-
 class GameBubble;
-class QSvgRenderer;
+
+#include <QWidget>
+
 
 class DemoBubbles : public QWidget
 {
@@ -23,14 +22,10 @@ signals:
     void gameSelected( int i );
 
 private:
-    QPixmap backPix, bubblePix;
     int games;
     int bubble_text_height, bubble_width, bubble_height;
 
     GameBubble *m_bubbles;
-
-    QSvgRenderer *bubblerenderer;
-
 };
 
 #endif // DEMO_H
