@@ -28,9 +28,9 @@
 #define GRANDF_H
 
 #include "dealer.h"
-
 class Pile;
 
+
 class Grandf : public DealerScene
 {
     friend class GrandfSolver;
@@ -40,16 +40,15 @@ public:
     Grandf( );
 
 public slots:
-    void redeal();
     void deal();
     virtual void restart();
+    virtual Card *newCards();
 
 protected:
     void collect();
     virtual bool checkAdd   ( int checkIndex, const Pile *c1, const CardList& c2) const;
-    virtual QString getGameState() const;
+    virtual QString getGameState();
     virtual void setGameState( const QString & stream );
-    virtual Card *demoNewCards();
 
 private:
     Pile* store[7];
