@@ -27,12 +27,15 @@
 #include <kgame/kgamepropertyarray.h>
 #include <kgame/kgameproperty.h>
 #include <kgame/kmessageio.h>
+#include <KGameSvgDocument>
+
+#include <KPixmapCache>
 
 #include <QPointF>
 #include <QString>
+#include <QSvgRenderer>
+#include <QMap>
 
-#include <map>
-#include <set>
 #include <iostream>
 
 namespace Ksirk {
@@ -53,10 +56,10 @@ enum KsirkMessagesIds {
     PlayerChange, // 260
     RegisterCountry, // 261
     PlayerAvailArmies, // 262
-    KGameWinAvailArmies, // 263
+    ResetPlayersDistributionData, // 263
     ChangeItem, // 264
     DisplayRecyclingButtons, // 265
-    DisplayNormalGameButtons, // 266
+    ClearHighlighting, // 266
     ActionRecycling, // 267
     ClearGameActionsToolbar, // 268
     DisplayDefenseButtons, // 269
@@ -65,10 +68,10 @@ enum KsirkMessagesIds {
     SecondCountry, // 272
     InitCombatMovement, // 273
     AnimCombat, // 274
-    DisplayInvasionButtons, // 275
+ // 275
     TerminateAttackSequence, // 276
     DecrNbArmies, // 277
-    DisplayNextPlayerButton, // 278
+    StartLocalCurrentAI, // 278
     Invade, // 279
     Retreat, // 280
     NextPlayerNormal, // 281
@@ -164,9 +167,16 @@ public:
     EXPLOSION_ANIMATE, 
     WAIT_PLAYERS, 
     GAME_OVER, // Game finished
-    INVALID
+    INVALID,
+    STARTING_GAME // when displaying the new game ui
   };
 
+  enum NetworkGameType {
+    None,
+    Socket,
+    Jabber
+  };
+  
   GameAutomaton();
   
   virtual ~GameAutomaton();
@@ -186,7 +196,7 @@ public:
     * @param event The event to register
     * @param point The point where the event occurred
     */
-  void gameEvent(const std::string& event, const QPointF& point);
+  void gameEvent(const QString& event, const QPointF& point);
   
   /** returns the name of the current state */
   QString stateName() const;
@@ -229,6 +239,7 @@ public:
     * @return the number of players playing from the network.
     */
   inline unsigned int networkPlayersNumber() {return m_networkPlayersNumber;}
+  inline void setNetworkPlayersNumber(unsigned int nb) {m_networkPlayersNumber = nb;}
   
   /** Retrives the game window. This one still contains too much game code 
     * that shouldn't be in a GUI class. */
@@ -273,8 +284,8 @@ public:
 
   //@{
   /** Accessors to the map associating messages to their ids */
-  inline std::map<quint32,QString>& ids2msgs() {return m_ids2msgs;}
-  inline std::map<QString,quint32>& msgs2ids() {return m_msgs2ids;}
+  inline QMap<quint32,QString>& ids2msgs() {return m_ids2msgs;}
+  inline QMap<QString,quint32>& msgs2ids() {return m_msgs2ids;}
   //@}
 
   //@{
@@ -285,13 +296,14 @@ public:
 
   //@{
   /** Accessors to the goals known by this game. */
-  inline const std::set< Goal* >& goals() const {return m_goals;}
-  inline std::set< Goal* >& goals() {return m_goals;}
+  inline const QList< Goal* >& goals() const {return m_goals;}
+  inline QList< Goal* >& goals() {return m_goals;}
   //@}
 
   /** If the game use goals, return true else (all players have to conquier the 
     * world) return false. */
   inline bool useGoals() {return m_useGoals;}
+  inline void setUseGoals(bool value) {m_useGoals = value;}
   
   //@{
   /** Accessors to the number of players of this game. */
@@ -308,8 +320,7 @@ public:
     * will contain the port on which we will wait for connections.
     * @param newPlayersNumber Will contain the number players of the new game.
     */
-  bool setupPlayersNumberAndSkin(bool& networkGame, int& port,
-                                 uint& newPlayersNumber);
+  bool setupPlayersNumberAndSkin(NetworkGameType netGameType);
   
     /**
      * Create an IO device like Mouse or Keyboard for the given player
@@ -334,10 +345,10 @@ public:
   
   //@{
   /** Some accessors to data really necessary... */
-  inline std::map< int, QString >& nbArmiesIdsNamesCountriesMap() {return m_nbArmiesIdsNamesCountriesMap;}
-  inline std::map< QString, int >& namesNbArmiesIdsCountriesMap() {return m_namesNbArmiesIdsCountriesMap;}
-  inline std::map< int, QString >& nbAddedArmiesIdsNamesCountriesMap() {return m_nbAddedArmiesIdsNamesCountriesMap;}
-  inline std::map< QString, int >& namesNbAddedArmiesIdsCountriesMap() {return m_namesNbAddedArmiesIdsCountriesMap;}
+  inline QMap< int, QString >& nbArmiesIdsNamesCountriesMap() {return m_nbArmiesIdsNamesCountriesMap;}
+  inline QMap< QString, int >& namesNbArmiesIdsCountriesMap() {return m_namesNbArmiesIdsCountriesMap;}
+//   inline QMap< int, QString >& nbAddedArmiesIdsNamesCountriesMap() {return m_nbAddedArmiesIdsNamesCountriesMap;}
+  inline QMap< QString, int >& namesNbAddedArmiesIdsCountriesMap() {return m_namesNbAddedArmiesIdsCountriesMap;}
   //@}
 
   void movingFigthersArrived();
@@ -372,6 +383,27 @@ public:
     */
   bool isDefenseAuto();
 
+  bool finishSetupPlayersNumberAndSkin(const QString& skin, NetworkGameType networkGame, uint newPlayersNumber);
+
+  inline int port() const {return m_port;}
+
+  void askForJabberGames();
+
+  bool startingGame() const;
+
+  KPixmapCache& pixmapCache() {return m_pixmapCache;}
+  QSvgRenderer& rendererFor(const QString& skinName);
+  KGameSvgDocument& svgDomFor(const QString& skinName);
+
+  inline NetworkGameType networkGameType() {return m_netGameType;}
+
+  bool joinJabberGame(const QString& nick);
+
+  void removeAllPlayers();
+  
+Q_SIGNALS:
+  void newJabberGame(const QString&, int, const QString&);
+    
 public Q_SLOTS:
   /** Reacts to the current state eventualy processing one queued event */
   GameState run();
@@ -422,7 +454,7 @@ public Q_SLOTS:
     */
   void slotConnectionToClientBroken(KMessageIO *);
 
-  Country * getDefCountry ();
+  Country* getDefCountry();
 
 private Q_SLOTS:
   void displayGoals();
@@ -451,7 +483,7 @@ protected:
   void setGoalFor(Player* player);
   
 private:
-  GameAutomaton(const GameAutomaton& /*ga*/) : KGame() {};
+  GameAutomaton(const GameAutomaton& /*ga*/) : KGame(), m_pixmapCache("GameAutomaton") {};
 
   void countriesDistribution();
 
@@ -467,10 +499,12 @@ private:
 
   void finalizePlayers();
   
-  void acknowledge(Player* player, unsigned int ack);
-
   void activateNeededAIPlayers();
 
+  void resetPlayersDistributionData();
+
+  void actionNextPlayer();
+  
   GameState m_state;
 //   KGameProperty< GameState > m_state;
 //     int m_stateId;
@@ -497,25 +531,25 @@ private:
   bool m_currentPlayerPlayed;
 //   int m_currentPlayerId;
   
-  std::map< int, QString > m_nbArmiesIdsNamesCountriesMap;
-  std::map< QString, int > m_namesNbArmiesIdsCountriesMap;
-  std::map< int, QString > m_nbAddedArmiesIdsNamesCountriesMap;
-  std::map< QString, int > m_namesNbAddedArmiesIdsCountriesMap;
+  QMap< int, QString > m_nbArmiesIdsNamesCountriesMap;
+  QMap< QString, int > m_namesNbArmiesIdsCountriesMap;
+//   QMap< int, QString > m_nbAddedArmiesIdsNamesCountriesMap;
+  QMap< QString, int > m_namesNbAddedArmiesIdsCountriesMap;
 
   quint32 m_choosedToRecycleNumber;
   
   QString m_savedPlayer;
   GameState m_savedState;
   
-  std::map<quint32,QString> m_ids2msgs;
-  std::map<QString,quint32> m_msgs2ids;
+  QMap<quint32,QString> m_ids2msgs;
+  QMap<QString,quint32> m_msgs2ids;
   
-  std::set< Goal* > m_goals;
+  QList< Goal* > m_goals;
   bool m_useGoals;
   
   quint32 m_nbPlayers;
 
-  std::set<int> m_choosedToRecycle;
+  QList<int> m_choosedToRecycle;
 
   // tell us if the automatic attack is enabled
   bool m_attackAuto;
@@ -543,6 +577,17 @@ private:
 
   // Save Defense country
   Country * defCountry;
+
+  int m_port;
+  
+  bool m_startingGame;
+
+  KPixmapCache m_pixmapCache;
+  QMap<QString, QSvgRenderer*> m_renderers;
+  QMap<QString, KGameSvgDocument> m_svgDoms;
+
+  NetworkGameType m_netGameType;
+
 };
 
 QDataStream& operator>>(QDataStream& s, GameAutomaton::GameState& state);
