@@ -88,8 +88,6 @@ Kubrick::Kubrick () :
     singmasterLabel->setFont (f);
     singmasterMoves->setFont (f);
 
-    adjustSize ();
-
     // Start the game with a randomised demo.
     game->initGame (gameView, this);
 }
@@ -221,7 +219,7 @@ void Kubrick::initGUI()
 				"and start a new puzzle with the same "
 				"dimensions and number of shuffling moves."));
 
-    QAction *
+    KAction *
     a =				KStandardGameAction::load (
 				game, SLOT (load()), this);
     actionCollection()->addAction (a->objectName(), a);
@@ -551,10 +549,10 @@ void Kubrick::initGUI()
 }
 
 
-QAction * Kubrick::mapAction (QSignalMapper * mapper, const QString & name,
+KAction * Kubrick::mapAction (QSignalMapper * mapper, const QString & name,
 		const QString & text, const Qt::Key key, SingmasterMove mapping)
 {
-    QAction * a;
+    KAction * a;
     a = actionCollection()->addAction (name);
     a->setText (text);
     a->setShortcut (key);
